@@ -245,7 +245,7 @@ SS_html <- function(replist=NULL,
                   '<pre>\n',
                   sep="", file=htmlfile, append=TRUE)
             }
-            for(irow in 3+(1:nwarn)){
+            for(irow in 3:length(replist$warnings)){
               cat(replist$warnings[irow],'\n',
                   sep="", file=htmlfile, append=TRUE)
             }
@@ -274,19 +274,6 @@ SS_html <- function(replist=NULL,
   # open HTML file automatically:
   if(openfile){
     cat("Opening HTML file in your default web-browser.\n")
-    if(.Platform$OS.type=="windows"){
-      shell.exec(file=htmlhome)
-      ## if(length(grep(" ",htmlhome))==0){
-      ##   shell(cmd=htmlhome,wait=FALSE)
-      ## }else{
-      ##   cat("Sorry, the path has a space in it which causes problems for the DOS command.\n",
-      ##       "      if you have a solution to this issue, let Ian T. know.\n",
-      ##       "      Please go open this file by hand:\n",
-      ##       htmlhome,"\n")
-      ## }
-    }else{
-      if(.Platform$GUI=="X11") system(paste("firefox",htmlhome), wait=FALSE)
-      if(.Platform$GUI=="Aqua") system(paste("open",htmlhome), wait=FALSE)
-    }
+    browseURL(htmlhome) # thanks John Wallace for finding this command
   }
 }
